.. _examples-handling:

Handling
========

Examples about **geotransformations** (e.g., reprojecting, cropping), raster-vector interfacing (e.g., rasterizing, polygonizing, geometric mask) and
raster-point interfacing (e.g., gridding points into a raster, interpolating or reducing a raster at points)

All of these methods support simply passing a reference to match (see :ref:`core-match-ref`).
